==> zio-aws-wafv2_2.13-5.17.128.1-sources.jar: zio/aws/wafv2/model/ManagedRuleSetSummary.scala <==
package zio.aws.wafv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.wafv2.model.primitives.{
  LockToken,
  LabelName,
  EntityId,
  ResourceArn,
  EntityDescription,
  EntityName
}
import scala.jdk.CollectionConverters._
final case class ManagedRuleSetSummary(
    name: Option[EntityName] = None,
    id: Option[EntityId] = None,
    description: Option[EntityDescription] = None,
    lockToken: Option[LockToken] = None,
    arn: Option[ResourceArn] = None,
    labelNamespace: Option[LabelName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary = {
    import ManagedRuleSetSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
      .builder()
      .optionallyWith(
        name.map(value => EntityName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        id.map(value => EntityId.unwrap(value): java.lang.String)
      )(_.id)
      .optionallyWith(
        description.map(value =>
          EntityDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        lockToken.map(value => LockToken.unwrap(value): java.lang.String)
      )(_.lockToken)
      .optionallyWith(
        arn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        labelNamespace.map(value => LabelName.unwrap(value): java.lang.String)
      )(_.labelNamespace)
      .build()
  }
  def asReadOnly: zio.aws.wafv2.model.ManagedRuleSetSummary.ReadOnly =
    zio.aws.wafv2.model.ManagedRuleSetSummary.wrap(buildAwsValue())
}
object ManagedRuleSetSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafv2.model.ManagedRuleSetSummary =
      zio.aws.wafv2.model.ManagedRuleSetSummary(
        name.map(value => value),
        id.map(value => value),
        description.map(value => value),
        lockToken.map(value => value),
        arn.map(value => value),
        labelNamespace.map(value => value)
      )
    def name: Option[EntityName]
    def id: Option[EntityId]
    def description: Option[EntityDescription]
    def lockToken: Option[LockToken]
    def arn: Option[ResourceArn]
    def labelNamespace: Option[LabelName]
    def getName: ZIO[Any, AwsError, EntityName] =
      AwsError.unwrapOptionField("name", name)
    def getId: ZIO[Any, AwsError, EntityId] =
      AwsError.unwrapOptionField("id", id)
    def getDescription: ZIO[Any, AwsError, EntityDescription] =
      AwsError.unwrapOptionField("description", description)
    def getLockToken: ZIO[Any, AwsError, LockToken] =
      AwsError.unwrapOptionField("lockToken", lockToken)
    def getArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getLabelNamespace: ZIO[Any, AwsError, LabelName] =
      AwsError.unwrapOptionField("labelNamespace", labelNamespace)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
  ) extends zio.aws.wafv2.model.ManagedRuleSetSummary.ReadOnly {
    override val name: Option[EntityName] = scala
      .Option(impl.name())
      .map(value => zio.aws.wafv2.model.primitives.EntityName(value))
    override val id: Option[EntityId] = scala
      .Option(impl.id())
      .map(value => zio.aws.wafv2.model.primitives.EntityId(value))
    override val description: Option[EntityDescription] = scala
      .Option(impl.description())
      .map(value => zio.aws.wafv2.model.primitives.EntityDescription(value))
    override val lockToken: Option[LockToken] = scala
      .Option(impl.lockToken())
      .map(value => zio.aws.wafv2.model.primitives.LockToken(value))
    override val arn: Option[ResourceArn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.wafv2.model.primitives.ResourceArn(value))
    override val labelNamespace: Option[LabelName] = scala
      .Option(impl.labelNamespace())
      .map(value => zio.aws.wafv2.model.primitives.LabelName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
  ): zio.aws.wafv2.model.ManagedRuleSetSummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wafv2_2.13-7.21.15.2-sources.jar: zio/aws/wafv2/model/ManagedRuleSetSummary.scala <==
package zio.aws.wafv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.wafv2.model.primitives.{
  LockToken,
  LabelName,
  EntityId,
  ResourceArn,
  EntityDescription,
  EntityName
}
import scala.jdk.CollectionConverters._
final case class ManagedRuleSetSummary(
    name: Optional[EntityName] = Optional.Absent,
    id: Optional[EntityId] = Optional.Absent,
    description: Optional[EntityDescription] = Optional.Absent,
    lockToken: Optional[LockToken] = Optional.Absent,
    arn: Optional[ResourceArn] = Optional.Absent,
    labelNamespace: Optional[LabelName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary = {
    import ManagedRuleSetSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
      .builder()
      .optionallyWith(
        name.map(value => EntityName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        id.map(value => EntityId.unwrap(value): java.lang.String)
      )(_.id)
      .optionallyWith(
        description.map(value =>
          EntityDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        lockToken.map(value => LockToken.unwrap(value): java.lang.String)
      )(_.lockToken)
      .optionallyWith(
        arn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        labelNamespace.map(value => LabelName.unwrap(value): java.lang.String)
      )(_.labelNamespace)
      .build()
  }
  def asReadOnly: zio.aws.wafv2.model.ManagedRuleSetSummary.ReadOnly =
    zio.aws.wafv2.model.ManagedRuleSetSummary.wrap(buildAwsValue())
}
object ManagedRuleSetSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafv2.model.ManagedRuleSetSummary =
      zio.aws.wafv2.model.ManagedRuleSetSummary(
        name.map(value => value),
        id.map(value => value),
        description.map(value => value),
        lockToken.map(value => value),
        arn.map(value => value),
        labelNamespace.map(value => value)
      )
    def name: Optional[EntityName]
    def id: Optional[EntityId]
    def description: Optional[EntityDescription]
    def lockToken: Optional[LockToken]
    def arn: Optional[ResourceArn]
    def labelNamespace: Optional[LabelName]
    def getName: ZIO[Any, AwsError, EntityName] =
      AwsError.unwrapOptionField("name", name)
    def getId: ZIO[Any, AwsError, EntityId] =
      AwsError.unwrapOptionField("id", id)
    def getDescription: ZIO[Any, AwsError, EntityDescription] =
      AwsError.unwrapOptionField("description", description)
    def getLockToken: ZIO[Any, AwsError, LockToken] =
      AwsError.unwrapOptionField("lockToken", lockToken)
    def getArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getLabelNamespace: ZIO[Any, AwsError, LabelName] =
      AwsError.unwrapOptionField("labelNamespace", labelNamespace)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
  ) extends zio.aws.wafv2.model.ManagedRuleSetSummary.ReadOnly {
    override val name: Optional[EntityName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.wafv2.model.primitives.EntityName(value))
    override val id: Optional[EntityId] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => zio.aws.wafv2.model.primitives.EntityId(value))
    override val description: Optional[EntityDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value => zio.aws.wafv2.model.primitives.EntityDescription(value))
    override val lockToken: Optional[LockToken] = zio.aws.core.internal
      .optionalFromNullable(impl.lockToken())
      .map(value => zio.aws.wafv2.model.primitives.LockToken(value))
    override val arn: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.wafv2.model.primitives.ResourceArn(value))
    override val labelNamespace: Optional[LabelName] = zio.aws.core.internal
      .optionalFromNullable(impl.labelNamespace())
      .map(value => zio.aws.wafv2.model.primitives.LabelName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.wafv2.model.ManagedRuleSetSummary
  ): zio.aws.wafv2.model.ManagedRuleSetSummary.ReadOnly = new Wrapper(impl)
}
